@@ -5,14 +5,14 @@ use warnings;
 
 # Added by eilara as hack around caller() core dump
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
-use Carp::Heavy                     (); 
-use Carp                            ();
-use Sub::Uplevel                    ();
-use Aspect::Hook                    ();
-use Aspect::Advice                  ();
-use Aspect::Context::AfterReturning ();
+use Carp::Heavy                   (); 
+use Carp                          ();
+use Sub::Uplevel                  ();
+use Aspect::Hook                  ();
+use Aspect::Advice                ();
+use Aspect::Point::AfterReturning ();
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -90,7 +90,7 @@ sub _install {
 					pointcut => \$pointcut,
 					original => \$original,
 					\%\$runtime,
-				}, 'Aspect::Context::AfterReturning';
+				}, 'Aspect::Point::AfterReturning';
 
 				# Execute the advice code
 				() = &\$code(\$context);
@@ -118,7 +118,7 @@ sub _install {
 					pointcut => \$pointcut,
 					original => \$original,
 					\%\$runtime,
-				}, 'Aspect::Context::AfterReturning';
+				}, 'Aspect::Point::AfterReturning';
 
 				# Execute the advice code
 				my \$dummy = &\$code(\$context);
@@ -143,7 +143,7 @@ sub _install {
 					pointcut => \$pointcut,
 					original => \$original,
 					\%\$runtime,
-				}, 'Aspect::Context::AfterReturning';
+				}, 'Aspect::Point::AfterReturning';
 
 				# Execute the advice code
 				&\$code(\$context);
