@@ -5,14 +5,14 @@ use warnings;
 
 # Added by eilara as hack around caller() core dump
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
-use Carp::Heavy             (); 
-use Carp                    ();
-use Sub::Uplevel            ();
-use Aspect::Hook            ();
-use Aspect::Advice          ();
-use Aspect::Context::Around ();
+use Carp::Heavy           (); 
+use Carp                  ();
+use Sub::Uplevel          ();
+use Aspect::Hook          ();
+use Aspect::Advice        ();
+use Aspect::Point::Around ();
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 our @ISA     = 'Aspect::Advice';
 
 sub _install {
@@ -82,7 +82,7 @@ sub _install {
 				pointcut     => \$pointcut,
 				original     => \$original,
 				\%\$runtime,
-			}, 'Aspect::Context::Around';
+			}, 'Aspect::Point::Around';
 
 			# Array context needs some special return handling
 			if ( \$wantarray ) {
