@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use Aspect::Modular         ();
 use Aspect::Advice::Before  ();
+use Aspect::Pointcut::And   ();
 use Aspect::Pointcut::Call  ();
 use Aspect::Pointcut::Cflow ();
-use Aspect::Pointcut::And   ();
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 our @ISA     = 'Aspect::Modular';
 
 sub get_advice {
@@ -131,30 +131,6 @@ defined on C<Page>, if it is in the call flow of C<Printer::print>:
 
   aspect Wormhole => 'Printer::Print', qr/^Page::/;
 
-=head1 SEE ALSO
-
-See the L<Aspect|::Aspect> pods for a guide to the Aspect module.
-
-You can find an example comparing the OO and AOP solutions in the
-C<examples/> directory of the distribution.
-
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
-
 =head1 AUTHORS
 
 Adam Kennedy E<lt>adamk@cpan.orgE<gt>
@@ -163,12 +139,7 @@ Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
 
 Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
-=head1 SEE ALSO
-
-You can find AOP examples in the C<examples/> directory of the
-distribution.
-
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
