@@ -5,7 +5,7 @@ use warnings;
 use Aspect::Pointcut        ();
 use Aspect::Pointcut::Logic ();
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 our @ISA     = qw{
 	Aspect::Pointcut::Logic
 	Aspect::Pointcut
@@ -47,7 +47,7 @@ sub match_curry {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested And clauses
+	# Collapse nested ::And clauses
 	while ( scalar grep { $_->isa('Aspect::Pointcut::And') } @list ) {
 		@list = map {
 			$_->isa('Aspect::Pointcut::And') ? @$_ : $_
@@ -114,32 +114,29 @@ __END__
 
 =head1 NAME
 
-Aspect::Pointcut::And - Logical 'and' operation pointcut
+Aspect::Pointcut::And - Logical 'and' pointcut
 
 =head1 SYNOPSIS
 
-    Aspect::Pointcut::And->new;
+  use Aspect;
+  
+  # High-level creation
+  my $pointcut1 = call 'one' & call 'two' & call 'three';
+  
+  # Manual creation
+  my $pointcut2 = Aspect::Pointcut::And->new(
+      Aspect::Pointcut::Call->new('one'),
+      Aspect::Pointcut::Call->new('two'),
+      Aspect::Pointcut::Call->new('three'),
+  );
 
 =head1 DESCRIPTION
 
-None yet.
+B<Aspect::Pointcut::And> is a logical condition, which is used
+to create higher-order conditions from smaller parts.
 
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+It takes two or more conditions, and applies appropriate logic during the
+various calculations that produces a logical set-wise 'and' result.
 
 =head1 AUTHORS
 
@@ -149,12 +146,7 @@ Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
 
 Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
-=head1 SEE ALSO
-
-You can find AOP examples in the C<examples/> directory of the
-distribution.
-
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
