@@ -6,13 +6,36 @@ use Carp             ();
 use Params::Util     ('_STRING', '_INSTANCE');
 use Aspect::Pointcut ();
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 our @ISA     = 'Aspect::Pointcut';
 
 
 
 
 
+######################################################################
+# Constructor
+
+sub new {
+	my $class = shift;
+	my $spec  = shift;
+	if ( Params::Util::_STRING($spec) ) {
+		my $perl = 'Params::Util::_INSTANCE(\$_->{exception}, "$spec")';
+		return bless [ $spec, sub { $_[0] eq $spec }, $perl ], $class;
+	}
+	if ( Params::Util::_CODELIKE($spec) ) {
+		return bless [ $spec, $spec, $spec ], $class;
+	}
+	unless ( Params::Util::_REGEX($spec) ) {
+		Carp::croak("Invalid function call specification");
+	}
+	return bless [ $spec,  ], $class;
+}
+
+
+
+
+
 ######################################################################
 # Weaving Methods
 
@@ -70,31 +93,18 @@ Aspect::Pointcut::Throwing - Exception typing pointcut
 
   use Aspect;
   
-  # Catch Foo exceptions and return true instead
-  after { $_[0]->return_value(1) } throwing 'Foo::Exception';
+  # Catch a Foo::Exception object exception
+  after {
+      $_[0]->return_value(1)
+  } throwing 'Foo::Exception';
+  
+  # Catch a plain die with particular string
 
 =head1 DESCRIPTION
 
 The B<Aspect::Pointcut::Throwing> pointcut is used to match situations
-in which an after() or after_throwing() advice returns a specific
-exception string or object.
-
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+in which an after() or after_throwing() advice block wishes to intercept
+the throwing of a specific exception string or object.
 
 =head1 AUTHORS
 
@@ -104,12 +114,7 @@ Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
 
 Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
-=head1 SEE ALSO
-
-You can find AOP examples in the C<examples/> directory of the
-distribution.
-
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
